/*******************************************************************************
* File Name: FRAM_I2C_I2C_BOOT.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the bootloader
*  communication interface of SCB component.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_FRAM_I2C_I2C_H)
#define CY_SCB_BOOT_FRAM_I2C_I2C_H

#include "FRAM_I2C_I2C_PVT.h"

#if (FRAM_I2C_I2C_SCB_MODE_I2C_INC)
    #include "FRAM_I2C_I2C_I2C.h"
#endif /* (FRAM_I2C_I2C_SCB_MODE_I2C_INC) */

#if (FRAM_I2C_I2C_SCB_MODE_EZI2C_INC)
    #include "FRAM_I2C_I2C_EZI2C.h"
#endif /* (FRAM_I2C_I2C_SCB_MODE_EZI2C_INC) */

#if (FRAM_I2C_I2C_SCB_MODE_SPI_INC || FRAM_I2C_I2C_SCB_MODE_UART_INC)
    #include "FRAM_I2C_I2C_SPI_UART.h"
#endif /* (FRAM_I2C_I2C_SCB_MODE_SPI_INC || FRAM_I2C_I2C_SCB_MODE_UART_INC) */


/***************************************
*        Function Prototypes
***************************************/

/* Bootloader communication interface enable */
#define FRAM_I2C_I2C_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_FRAM_I2C_I2C) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

#if (FRAM_I2C_I2C_SCB_MODE_I2C_INC)

    #define FRAM_I2C_I2C_I2C_BTLDR_COMM_ENABLED     (FRAM_I2C_I2C_BTLDR_COMM_ENABLED && \
                                                            (FRAM_I2C_I2C_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             FRAM_I2C_I2C_I2C_SLAVE_CONST))

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (FRAM_I2C_I2C_I2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void FRAM_I2C_I2C_I2CCyBtldrCommStart(void);
    void FRAM_I2C_I2C_I2CCyBtldrCommStop (void);
    void FRAM_I2C_I2C_I2CCyBtldrCommReset(void);
    cystatus FRAM_I2C_I2C_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus FRAM_I2C_I2C_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Size of Read/Write buffers for I2C bootloader  */
    #define FRAM_I2C_I2C_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
    #define FRAM_I2C_I2C_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)
    #define FRAM_I2C_I2C_I2C_MIN_UINT16(a, b)           ( ((uint16)(a) < (uint16) (b)) ? \
                                                                    ((uint32) (a)) : ((uint32) (b)) )
    #define FRAM_I2C_I2C_WAIT_1_MS                      (1u)
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (FRAM_I2C_I2C_I2C_BTLDR_COMM_ENABLED) */

#endif /* (FRAM_I2C_I2C_SCB_MODE_I2C_INC) */


#if (FRAM_I2C_I2C_SCB_MODE_EZI2C_INC)

    /* Provide EMPTY bootloader communication functions. EZI2C is NOT supported yet */
    #define FRAM_I2C_I2C_EZI2C_BTLDR_COMM_ENABLED   (FRAM_I2C_I2C_BTLDR_COMM_ENABLED && \
                                                         FRAM_I2C_I2C_SCB_MODE_UNCONFIG_CONST_CFG)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (FRAM_I2C_I2C_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void FRAM_I2C_I2C_EzI2CCyBtldrCommStart(void);
    void FRAM_I2C_I2C_EzI2CCyBtldrCommStop (void);
    void FRAM_I2C_I2C_EzI2CCyBtldrCommReset(void);
    cystatus FRAM_I2C_I2C_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus FRAM_I2C_I2C_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (FRAM_I2C_I2C_EZI2C_BTLDR_COMM_ENABLED) */

#endif /* (FRAM_I2C_I2C_SCB_MODE_EZI2C_INC) */

#if (FRAM_I2C_I2C_SCB_MODE_SPI_INC || FRAM_I2C_I2C_SCB_MODE_UART_INC)
    /* Provide EMPTY bootloader communication functions. SPI and UART is NOT supported yet */
    #define FRAM_I2C_I2C_SPI_BTLDR_COMM_ENABLED     (FRAM_I2C_I2C_BTLDR_COMM_ENABLED && \
                                                        FRAM_I2C_I2C_SCB_MODE_UNCONFIG_CONST_CFG)

    #define FRAM_I2C_I2C_UART_BTLDR_COMM_ENABLED    (FRAM_I2C_I2C_BTLDR_COMM_ENABLED && \
                                                        FRAM_I2C_I2C_SCB_MODE_UNCONFIG_CONST_CFG)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (FRAM_I2C_I2C_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void FRAM_I2C_I2C_SpiCyBtldrCommStart(void);
    void FRAM_I2C_I2C_SpiCyBtldrCommStop (void);
    void FRAM_I2C_I2C_SpiCyBtldrCommReset(void);
    cystatus FRAM_I2C_I2C_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus FRAM_I2C_I2C_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (FRAM_I2C_I2C_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (FRAM_I2C_I2C_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void FRAM_I2C_I2C_UartCyBtldrCommStart(void);
    void FRAM_I2C_I2C_UartCyBtldrCommStop (void);
    void FRAM_I2C_I2C_UartCyBtldrCommReset(void);
    cystatus FRAM_I2C_I2C_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus FRAM_I2C_I2C_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (FRAM_I2C_I2C_UART_BTLDR_COMM_ENABLED) */

#endif /* (FRAM_I2C_I2C_SCB_MODE_SPI_INC || FRAM_I2C_I2C_SCB_MODE_UART_INC) */

#if !defined (FRAM_I2C_I2C_I2C_BTLDR_COMM_ENABLED)
    #define FRAM_I2C_I2C_I2C_BTLDR_COMM_ENABLED     (0u)
#endif /* (FRAM_I2C_I2C_I2C_BTLDR_COMM_ENABLED) */

#if !defined (FRAM_I2C_I2C_EZI2C_BTLDR_COMM_ENABLED)
    #define FRAM_I2C_I2C_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (FRAM_I2C_I2C_EZI2C_BTLDR_COMM_ENABLED) */

#if !defined (FRAM_I2C_I2C_SPI_BTLDR_COMM_ENABLED)
    #define FRAM_I2C_I2C_SPI_BTLDR_COMM_ENABLED     (0u)
#endif /* (FRAM_I2C_I2C_SPI_BTLDR_COMM_ENABLED) */

#if !defined (FRAM_I2C_I2C_UART_BTLDR_COMM_ENABLED)
    #define FRAM_I2C_I2C_UART_BTLDR_COMM_ENABLED    (0u)
#endif /* (FRAM_I2C_I2C_UART_BTLDR_COMM_ENABLED) */

/* Bootloader enabled condition for each mode */
#define FRAM_I2C_I2C_BTLDR_COMM_MODE_ENABLED    (FRAM_I2C_I2C_I2C_BTLDR_COMM_ENABLED   || \
                                                     FRAM_I2C_I2C_EZI2C_BTLDR_COMM_ENABLED || \
                                                     FRAM_I2C_I2C_SPI_BTLDR_COMM_ENABLED   || \
                                                     FRAM_I2C_I2C_UART_BTLDR_COMM_ENABLED)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (FRAM_I2C_I2C_BTLDR_COMM_ENABLED)
    #if (FRAM_I2C_I2C_BTLDR_COMM_MODE_ENABLED)
        /* Bootloader physical layer functions */
        void FRAM_I2C_I2C_CyBtldrCommStart(void);
        void FRAM_I2C_I2C_CyBtldrCommStop (void);
        void FRAM_I2C_I2C_CyBtldrCommReset(void);
        cystatus FRAM_I2C_I2C_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus FRAM_I2C_I2C_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (FRAM_I2C_I2C_BTLDR_COMM_MODE_ENABLED) */

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_FRAM_I2C_I2C)
        #define CyBtldrCommStart    FRAM_I2C_I2C_CyBtldrCommStart
        #define CyBtldrCommStop     FRAM_I2C_I2C_CyBtldrCommStop
        #define CyBtldrCommReset    FRAM_I2C_I2C_CyBtldrCommReset
        #define CyBtldrCommWrite    FRAM_I2C_I2C_CyBtldrCommWrite
        #define CyBtldrCommRead     FRAM_I2C_I2C_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_FRAM_I2C_I2C) */
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (FRAM_I2C_I2C_BTLDR_COMM_ENABLED) */

#endif /* (CY_SCB_BOOT_FRAM_I2C_I2C_H) */

/* [] END OF FILE */
